@@ -1,6 +1,6 @@
 #ifndef CONFIGWEBENGINEVIEWER_H
 #define CONFIGWEBENGINEVIEWER_H
 
-/* #undef WEBENGINEVIEWER_PRINT_SUPPORT */
+#define WEBENGINEVIEWER_PRINT_SUPPORT 1
 
 #endif
